#!/bin/bash
#
#  Copyright 2005 Nullriver, Inc. All rights reserved.

#  <1:moviesource> <2:movietitle> <3:moviedestination> <4:thumbdestination> <5:videoresolution> <6:videoquality> <7:audioquality> <8:usequicktime> <9:deinterlace> <10:volumeboost> <11:isdvdvob> <12:vobpath> 

if [ ! $11 ]; then 
	echo "Wrong parameter count!"
	exit 1; 
fi;

# Set video resolution
case $5 in
	0)
	VIDEO_RESOLUTION="320x240";
	ASPECT="4:3";;
	1)
	VIDEO_RESOLUTION="368x208";
	ASPECT="16:9";;
esac

# Set video quality
case $6 in
	0)
	FRAME_RATE=14.985;
	VIDEO_BITRATE=160;
	HIGH_QUALITY=false;;
	1)
	FRAME_RATE=29.97;
	VIDEO_BITRATE=192;
	HIGH_QUALITY=false;;
	2)
	FRAME_RATE=29.97;
	VIDEO_BITRATE=302;
	HIGH_QUALITY=false;;
	3)
	FRAME_RATE=29.97;
	VIDEO_BITRATE=604;
	HIGH_QUALITY=false;;
	4)
	FRAME_RATE=29.97;
	VIDEO_BITRATE=768;
	HIGH_QUALITY=false;;
esac

# Set audio quality
case $7 in
	0)
	AUDIO_HZ=24000;
	AUDIO_BITRATE=16;;
	1)
	AUDIO_HZ=24000;
	AUDIO_BITRATE=32;;
	2)
	AUDIO_HZ=24000;
	AUDIO_BITRATE=64;;
	3)
	AUDIO_HZ=24000;
	AUDIO_BITRATE=96;;
	4)
	AUDIO_HZ=24000;
	AUDIO_BITRATE=128;;
esac

#TOTAL_BITRATE=$VIDEO_BITRATE+$AUDIO_BITRATE;
#if [ $TOTAL_BITRATE > 768 ]; then
#	VIDEO_BITRATE=704;
#	AUDIO_BITRATE=64;
#fi

# Set whether we use quicktime decoding
case $8 in
	0)
	USE_QUICKTIME=false;;
	1)
	USE_QUICKTIME=true;;
esac

# Set whether we deinterlace
case $9 in
	0)
	DEINTERLACE=false;;
	1)
	DEINTERLACE=true;;
esac

VOLUME_BOOST=${10};

# Is this a DVD VOB file?
case $11 in
	0)
	IS_DVDVOB=false;;
	1)
	IS_DVDVOB=true;;
esac

VOB_PATH=${12};


##################################################

# Prepare
if [ $HIGH_QUALITY == true ]; then
	HQ_MODIFIER="-hq";
fi

if [ $DEINTERLACE == true ]; then
	DEINTERLACE_MODIFIER="-deinterlace";
fi

PREFIX="./ffmpeg -i \"${1}\""

if [ $USE_QUICKTIME == true ]; then
	./mov123 "$1" > /tmp/PSPWare.movaudio
	if [ -s /tmp/PSPWare.movaudio ]; then
		PREFIX="./movtoy4m -a ${ASPECT} \"${1}\" | ./ffmpeg -f s16be -ac 2 -i /tmp/PSPWare.movaudio -f yuv4mpegpipe -i -"
		echo MOVINFO: `./movinfo "$1"` :MOVINFO
	fi
fi

# DVD vob movie support
if [ $IS_DVDVOB == true ]; then
	echo "Converting DVD VOB movie..."
	if [ -f "${10}/VTS_03_0.VOB" ]; then
    	PREFIX="cat \"${10}/\"VTS_0[3-9]*.VOB \"${10}/\"VTS_[1-9][0-9]*.VOB | ./ffmpeg -f vob -i pipe:"
    else
    	PREFIX="cat \"${10}/\"VTS_0[1-2]*.VOB | ./ffmpeg -f vob -i pipe:"
    fi
fi

# Begin conversion
POSTFIX="-f s16be -ac 2 -i \"Silence.wav\"		\
		-f psp									\
		-vcodec mpeg4							\
		-acodec aac								\
		-ac 2									\
		-ar ${AUDIO_HZ}							\
		-ab ${AUDIO_BITRATE}					\
		-vol ${VOLUME_BOOST}					\
		-b ${VIDEO_BITRATE}						\
		-r ${FRAME_RATE}						\
		-s ${VIDEO_RESOLUTION}					\
		-aspect ${ASPECT}						\
		${HQ_MODIFIER}							\
		${DEINTERLACE_MODIFIER}					\
		-title \"${2}\"							\
		-threads 4								\
		-y										\
		\"${3}\""

eval "${PREFIX} ${POSTFIX}" || exit 1;


# Create thumb file
./movtoy4m -a ${ASPECT} "$3" | ./ffmpeg -f yuv4mpegpipe -i - -y -s 160x120 -r 1 -t 1 -ss 3 -an -f singlejpeg "$4" || exit 1;

# Clean up
if [ -f /tmp/PSPWare.movaudio ]; then
	rm -f /tmp/PSPWare.movaudio;
fi